pub trait SelectorManager { // Required method fn stop(&mut self); }
Selector manager used to stop the selector thread
Stop the selector thread Note that we do not take self by value to consume it because it is not allowed to move out of Box<dyn SelectorManager> This will improve if the unsized_fn_params feature stabilizes enough to be safely usable.
Box<dyn SelectorManager>
unsized_fn_params